<template>
  <div class="Spatialbox">
    <My-bread
      :list="[
        `${$t('dataManage.dataManage')}`,
        `${$t('dataManage.dataRetrieval')}`,
      ]"
    ></My-bread>
    <el-divider />
    <div class="spatialContent">
      <div class="spatial_leftTree">
        <el-tree
          :data="tree"
          :props="defaultProps"
          :default-expanded-keys="[1]"
          node-key="id"
          @node-click="handleNodeClick"
        ></el-tree>
      </div>
      <div class="spatial_rightContent">
        <el-form ref="ruleForm" :model="ruleForm" :inline="true">
          <el-form-item :label="$t('dataManage.vmobj.keyword')" prop="name">
            <el-input v-model="ruleForm.name" :placeholder="$t('common.choose')" />
          </el-form-item>
          <el-form-item>
            <el-button
              @click="submitForm('ruleForm')"
              icon="el-icon-search"
              class="primary"
              size="small"
              >{{$t('common.iquery')}}</el-button
            >
            <el-button
              @click="resetForm('ruleForm')"
              icon="el-icon-refresh"
              type="info"
              size="small"
              >{{$t('common.reset')}}</el-button
            >

            <el-button
              v-if="btnStatus.download"
              icon="el-icon-position"
              type="success"
              size="small"
              >{{$t('common.download')}}</el-button
            >
          </el-form-item>
        </el-form>
        <el-divider class="eldivider" />
        <div style="height: 85%">
          <el-table
            ref="filterTable"
            :data="tableData"
            height="90%"
            border
            style="width: 100%"
            @selection-change="handleSelectionChange"
          >
            <el-table-column type="selection" width="55" />
            <el-table-column width="60" type="index" :label="$t('common.index')" />
            <el-table-column
              v-for="(item, index) in attributeData"
              :key="index"
              :label="item.alias"
              :prop="item.field"
              show-overflow-tooltip
              align="center"
            ></el-table-column>
            <el-table-column min-width="80" :label="$t('common.operate')">
              <template slot-scope="scope">
                <el-link class="elLink"

                  @click="showDetail(scope.$index, scope.row)"
                  >{{$t('common.details')}}</el-link
                >
                <el-link class="elLink"
                  @click="dialogFormVisible = true"
                  style="margin-left: 20px;  "
                  >{{$t('common.enclosure')}}</el-link
                >
              </template>
            </el-table-column>
          </el-table>
          <div style="margin-top: 20px" class="pagination_box">
            <el-pagination
              v-if="changePag"
              @size-change="handleSizeChange"
              @current-change="handleCurrentChange"
              :current-page="this.listData.pageIndex"
              :page-sizes="[10, 20, 50, 100]"
              :page-size="this.listData.pageSize"
              layout="total, sizes, prev, pager, next, jumper"
              :total="count"
            >
            </el-pagination>
          </div>
        </div>
      </div>
    </div>
        <div class="infoBox" v-show="showinfoBox">
      <el-card class="box-card">
        <div slot="header" class="clearfix">
          <span>{{$t('common.details')}}</span>
          <div style="float: right; cursor: pointer" @click="closeDetial">
            <i class="el-icon-close"></i>
          </div>
        </div>
        <div class="contentBox">
          <ul>
            <li v-for="(item, index) in itemdetail">
              <p>
                <label> {{ item.label }}:</label>
                <label class="boxlabel">{{ item.value }}</label>
              </p>
              <el-divider></el-divider>
            </li>
          </ul>
        </div>
      </el-card>
    </div>
    <el-dialog :title="$t('common.attachinform')" width="30%" :visible.sync="dialogFormVisible">
      <el-form :model="formInline" class="demo-form-inline">
        <el-form-item >
          <el-input
            v-model="formInline.file"
            style="width: 300px; margin-right: 20px"
            :placeholder="$t('common.choose')"
            disabled
          ></el-input>
          <input
            name="file1"
            type="file"
            id="insertFile"
            multiple="multiple"
            style="display: none"
              @change="insertFile( )"
          />
          <el-link  @click="getInsertFile( )" :underline="false"
            ><i class="el-icon-folder-opened"></i
          ></el-link>
        </el-form-item>
        <el-form-item>
          <el-row  >
            <el-col :span="3"> <el-link  class="elLink" :underline="false" >{{$t('common.append')}}</i></el-link></el-col>
            <el-col :span="3">   <el-link  class="elLink" :underline="false" >{{$t('common.delete')}}</i></el-link></el-col>
            <el-col :span="3">  <el-link  class="elLink" :underline="false" >{{$t('common.reset')}}</i></el-link></el-col>
          </el-row>
        </el-form-item>
        <el-form-item>
 <el-table
            ref="filterTable"
            height="99%"
            border
            style="width: 100%"
          >
          <el-table-column width="60" type="index" :label="$t('common.index')" />
              <el-table-column  prop="date"
         :label="$t('common.fileNme')"
         />

      <el-table-column
        prop="name"
        :label="$t('common.filePath')"
        />

           </el-table>
        </el-form-item>
        <el-form-item>

<el-row :gutter="20">
  <el-col :span="12" :offset="8">  <el-button  class="primary" @click="dialogFormVisible = false">确认</el-button>  <el-button type="info"   @click="dialogFormVisible = false">取消</el-button></el-col>
</el-row>
        </el-form-item>
      </el-form>

    </el-dialog>
  </div>
</template>

<script>
import $ from 'jquery';
import {
  dataQuery_selectTabs,
  dataQuery_selectDomains,
  dataQuery_selectFields,
  dataQuery_selectByPage,
} from '../../api/api';

import catalogueTree from '../../components/catalogueTree.vue';
import MyBread from '../../components/MyBread.vue';
export default {
  //import引入的组件需要注入到对象中才能使用
  name: 'dataSearch',
  components: { MyBread, catalogueTree },
  data() {
    return {
      formInline: {
        file: '',
      },
      tree: [
        {
          tabDesc: '基础数据',
          value: 'BD',
          children: [],
        },
        {
          tabDesc: '业务数据',
          value: 'BS',
          children: [],
        },
      ],
      defaultProps: {
        children: 'children',
        label: 'tabDesc',
      },
      btnStatus: {
        select: false,
        delete: false,
        upload: false,
        download: false,
        insert: false,
        update: false,
      },
      tableType: null,
      ruleForm: {
        name: null,
      },
      FBtest: false,
      tableData: [],
      formLabelWidth: '120px',
      dialogFormVisible: false,
      upform: {
        gid: '',
        pipename: '',
        sitename: '',
        type: '',
        seriesname: '',
        stationvalue: '',
        transportm: '',
        diameter: '',
        name: '',
      },

      changePag: true,
      showinfoBox: false,
      itemdetail: {},

      tableData: [],
      attributeData: [],
      currentPage: 1,
      searchName: '',
      multipleSelection: [],
      filedsLayer: null,
      count: 0,
      listData: {
        pageSize: 10,
        pageIndex: 1,
        name: null,
        filter: null,
        wkt: null,
      },
    };
  },
  created() {
    // this.getSPData(10, 1, "");
    // this.getSPCount("");
    this.showPermsBtn();
    this.getTreeDataAll();
  },
  methods: {
    //附件=>文件选择
    getInsertFile() {
      $('#insertFile').click();
    },
    insertFile() {
      var val = document.getElementById('insertFile').files;
      if (!val || !val.length) return;

      this.formInline.file = val[0].name;
    },
    //获取目录树数据
    async getTreeDataAll() {
      const data = await dataQuery_selectTabs();
      if (data.code != 200) {
        this.$message.error('列表调用失败');
      }
      var option = data.result;

      for (var i in option) {
        var val_Data = option[i];
        val_Data.id = '1' + i;
        if (option[i].ns == 'bd') {
          this.tree[0].children.push(val_Data);
        } else {
          this.tree[1].children.push(val_Data);
        }
      }
    },
    //授权管理
    showPermsBtn() {
      let currentPerms = this.$store.state.currentPerms;
      let permsEntity = this.$store.state.permsEntity;
      permsEntity
        .filter((item) => item.perms == currentPerms)
        .map((item) => {
          console.log(item);
          this.btnStatus[item.tag.substr(1)] = true;
        });
    },
    //树点击事件
    handleNodeClick(data) {
      //判断点击是否为子节点
      if (data.children != null) return;
      this.listData.name = data.entity; //要查询表格类型；

      this.filedsLayer = this.getCollapseDomFiled(); //获取每个表字段名称及阈值
      //获取table信息
      this.getCollapseTable(this.filedsLayer);
    },
    //获取表格信息
    async getCollapseTable(res) {
      res.then((val) => {
        this.attributeData = val;
      });
      if (this.ruleForm.name != null) {
        this.listData.filter = 'name like ' + this.ruleForm.name;
      } else {
        this.listData.filter = null;
      }

      const data = await dataQuery_selectByPage(this.listData);
      if (data.code != 200) {
        this.$message.error('调用列表失败,请联系工作人员!');
        return;
      }
      var res_val = this.attributeData;
      this.count = data.count;
      for (var i in data.result) {
        let val_Data = data.result[i];

        for (var j in res_val) {
          if (res_val[j].domainNa != null && res_val[j].domainNa != undefined) {
            val_Data[res_val[j].field] = res_val[j].domainNa;
          }
        }
      }
      this.tableData = data.result;
    },
    //获取每个表字段名称及阈值
    async getCollapseDomFiled() {
      //查询字段信息;
      const fileds = await dataQuery_selectFields({
        name: this.listData.name,
      });
      if (fileds.code != 200) {
        this.$message.error('调用列表失败,请联系工作人员!');
        return;
      }

      //查询阈值信息；
      const domains = await dataQuery_selectDomains({
        name: this.listData.name,
      });
      if (domains.code != 200) {
        this.$message.error('调用列表失败,请联系工作人员!');
        return;
      }
      var data1 = fileds.result;
      var data2 = domains.result;
      var std = [];
      for (var i in data1) {
        if (data1[i].showtype == 1) {
          if (data1[i].domainNa != null) {
            data1[i].domainNa = this.getDomainNaFild(data1[i].domainNa, data2);
          }
          std.push(data1[i]);
        }
      }
      return std;
    },
    //值域字段匹配
    getDomainNaFild(res, result) {
      for (var i in result) {
        if (result[i].domName == res) {
          return result[i].codeDesc;
        }
      }
      return null;
    },
    // 请求场站点内容
    getSPData(size, num, name) {
      querySitePoint(size, num, name).then((res) => {
        this.tableData = res.data;
      });
    },
    // 请求场站点数量
    getSPCount(name) {
      querySitePointCount(name).then((res) => {
        this.count = res.data;
      });
    },
    // 请求场站点内容
    getSSData(size, num, name) {
      queryStationSeries(size, num, name).then((res) => {
        this.tableData = res.data;
      });
    },
    // 请求场站点数量
    getSSCount(name) {
      queryStationSeriesCount(name).then((res) => {
        this.count = res.data;
      });
    },

    // 请求标桩内容
    getMData(size, num, name) {
      queryMarker(size, num, name).then((res) => {
        this.tableData = res.data;
      });
    },
    // 请求标桩数量
    getMCount(name) {
      queryMarkerCount(name).then((res) => {
        this.count = res.data;
      });
    },

    // 关键字查询
    submitForm() {
      this.listData.pageIndex = 1;
      this.listData.pageSize = 10;
      //获取table信息
      this.getCollapseTable(this.filedsLayer);
    },
    //分页点击事件
    handleSizeChange(val) {
      this.listdata.pageSize = val;
      this.listdata.pageIndex = 1;
      //获取table信息
      this.getCollapseTable(this.filedsLayer);
    },
    handleCurrentChange(val) {
      this.listdata.pageIndex = val;
      //获取table信息
      this.getCollapseTable(this.filedsLayer);
    },
    // 重置查询
    resetForm(formName) {
      this.searchName = '';
      this.$refs[formName].resetFields();
      //获取table信息
      this.getCollapseTable(this.filedsLayer);
    },

    // 发布按钮
    testfb() {
      // if (this.FBtest) {
      //   this.$confirm("是否取消发布?", "提示", {
      //     confirmButtonText: "确定",
      //     cancelButtonText: "取消",
      //     type: "warning",
      //   })
      //     .then(() => {
      const loading = this.$loading({
        lock: true,
        text: 'Loading',
        spinner: 'el-icon-loading',
        background: 'rgba(0, 0, 0, 0.7)',
      });
      setTimeout(() => {
        loading.close();
        this.FBtest = !this.FBtest;
      }, 2000);
      // })
      // .catch(() => {});
      // }
    },
    // 查看界面
    showDetail(index, row) {
      console.log(index, row);
      console.log(this.attributeData);
      this.showinfoBox = true;

      var std = [];
      for (var i in this.attributeData) {
        std.push({
          label: this.attributeData[i].alias,
          value: row[this.attributeData[i].field],
        });
      }
      this.itemdetail = std;
    },
    // 关闭查看
    closeDetial() {
      this.showinfoBox = false;
      this.itemdetail = {};
    },

    // 修改界面
    handleEdit(index, row) {
      this.dialogFormVisible = true;
      this.upform = JSON.parse(JSON.stringify(row));
    },
    // 提交修改
    updateForm() {
      let params = {};
      this.$confirm('是否确定编辑?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
        .then(() => {
          this.dialogFormVisible = false;
          switch (this.tableType) {
            case '场站点':
              params = {
                gid: this.upform.gid,
                pipename: this.upform.pipename,
                sitename: this.upform.sitename,
                type: this.upform.type,
              };
              UpdateSitePoint(params).then((res) => {
                if (res.data == 1) {
                  this.$message({
                    message: '修改成功',
                    type: 'success',
                  });
                }
                this.getSPData(10, 1, '');
                this.getSPCount('');
              });
              break;
            case '管道中心线':
              params = {
                gid: this.upform.gid,
                pipename: this.upform.pipename,
                seriesname: this.upform.seriesname,
                stationvalue: this.upform.stationvalue,
                transportm: this.upform.transportm,
                diameter: this.upform.diameter,
              };
              UpdateStationSeries(params).then((res) => {
                if (res.data == 1) {
                  this.$message({
                    message: '修改成功',
                    type: 'success',
                  });
                }
                this.getSSData(10, 1, '');
                this.getSSCount('');
              });
              break;
            case '标桩':
              params = {
                gid: this.upform.gid,
                pipename: this.upform.pipename,
                name: this.upform.name,
                type: this.upform.type,
              };
              UpdatgeMarker(params).then((res) => {
                if (res.data == 1) {
                  this.$message({
                    message: '修改成功',
                    type: 'success',
                  });
                }
                this.getMData(10, 1, '');
                this.getMCount('');
              });
              break;
          }
          // updateMetaData(this.upform).then((res) => {
          //   if (res.data == 1) {
          //     this.$message({
          //       message: "修改成功",
          //       type: "success",
          //     });
          //   }
          //   this.getMetaData(10, 1, "");
          //   this.getMetaCount("");
          // });
        })
        .catch(() => {});
    },
    // 获取多选选中的对象
    handleSelectionChange(val) {
      this.multipleSelection = val;
    },
    // 删除多条
    DelFormData() {
      var std = [];
      for (var i in this.multipleSelection) {
        std.push(this.multipleSelection[i].gid);
      }
      this.$confirm('确定是否删除所选内容?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
        .then(() => {
          switch (this.tableType) {
            case '场站点':
              dltSitePoint(std).then((res) => {
                if (res.data !== 0) {
                  this.$message({
                    message: '删除成功',
                    type: 'success',
                  });
                }
                this.getSPData(10, 1, '');
                this.getSPCount('');
              });
              break;
            case '管道中心线':
              dltStationSeries(std).then((res) => {
                if (res.data !== 0) {
                  this.$message({
                    message: '删除成功',
                    type: 'success',
                  });
                }
                this.getSSData(10, 1, '');
                this.getSSCount('');
              });
              break;
            case '标桩':
              dltMarker(std).then((res) => {
                if (res.data !== 0) {
                  this.$message({
                    message: '删除成功',
                    type: 'success',
                  });
                }
                this.getMData(10, 1, '');
                this.getMCount('');
              });
              break;
          }
          // dltMetaDatas(std).then((res) => {
          //   this.getMetaData(10, 1, "");
          //   this.getMetaCount("");
          //   this.$message({
          //     type: "success",
          //     message: "删除成功!",
          //   });
          // });
        })
        .catch(() => {});
    },
  },
};
</script>
<style lang="less" scoped>
//@import url(); 引入公共css类
.Spatialbox {
  height: 81%;
  width: 97%;
  position: absolute;

  box-sizing: border-box;
  .spatialContent {
    width: 100%;
    height: 92%;
    display: flex;
    justify-content: space-between;

    .spatial_leftTree {
      width: 15%;
      height: 95%;
      border: 1px solid white;
      border-radius: 5px;
      padding: 1%;
      max-height: 670px;
      overflow-y: auto;
    }
    .spatial_rightContent {
      width: 80%;
      height: 95%;
      border: 1px solid white;
      border-radius: 5px;
      padding: 1%;
      overflow-y: auto;
    }
  }
  .primary {
    background: #409eff;
    border: #409eff;
    color: white;
  }
  .eldivider {
    margin-top: 0px;
  }
  /deep/.el-form-item__label {
    color: white;
  }
  // 设置输入框的背景色、字体颜色、边框属性设置；
  /deep/.el-input__inner {
    background-color: transparent !important ;
    color: #fff;
    border: 1px solid;
  }
  /*修改table 表体的背景颜色和文字颜色*/
  /deep/ .el-table {
    background-color: transparent;

    th,
    td {
      background-color: transparent;
    }
    .el-table__expanded-cell {
      background-color: transparent !important;
    }

    // 表头背景色
    th.el-table__cell {
      background-color: #303030;
      color: #fff;
    }
    tr > td {
      background-color: #303030;
      color: #fff;
    }

    // hover效果
    tr:hover > td {
      background-color: rgba(255, 255, 255, 0.3) !important;
    }

    tbody tr:hover {
      background-color: rgba(255, 255, 255, 0.3) !important;
      // text-align: center;
    }

    // 滚动条宽高
    .el-table__body-wrapper::-webkit-scrollbar {
      width: 5px;
      height: 5px;
    }

    .el-table__body-wrapper::-webkit-scrollbar {
      width: 5px;
      /*滚动条宽度*/
      height: 5px;
      /*滚动条高度*/
    }
    /*定义滚动条轨道 内阴影+圆角*/
    .el-table__body-wrapper::-webkit-scrollbar-track {
      box-shadow: 0px 1px 3px #216fe6 inset;
      /*滚动条的背景区域的内阴影*/
      border-radius: 10px;
    }

    /*定义滑块 内阴影+圆角*/
    .el-table__body-wrapper::-webkit-scrollbar-thumb {
      box-shadow: 0px 1px 3px #216fe6 inset;
      border-radius: 6px;
      background-color: #216fe6;
    }
  }
    .infoBox {
    width: 500px;

    position: absolute;
    z-index: 100;
    top: 15%;
    right: 15%;
    background-color: #303030;
    color: white;
    .el-card {
      background-color: transparent;
         color: white;
      span {
        font-size: 16px;
        font-weight: 600;
           color: white;
      }
    }
    .contentBox {
      margin: 0 aotu 10px;
      p {
   color: white;
        font-size: 14px;
      }
    }
  }

  .pagination_box {
    margin-top: 20px;
    /deep/.el-input__inner {
      background-color: transparent !important;
      border: 1px solid;
      color: white;
    }
    /deep/.el-pagination__total {
      color: white;
    }
    /deep/.el-pagination__jump {
      color: white;
    }
    /deep/.el-pager li.active {
      color: #409eff;
    }
    /deep/.el-pager li {
      color: white;
      background: transparent;
    }
    /deep/.el-pager li {
      color: white;
    }
    /deep/.btn-prev {
      background: transparent;
    }
    /deep/.btn-next {
      background: transparent;
    }
    /deep/.btn-next i {
      color: white;
    }
    /deep/.btn-prev i {
      color: white;
    }
  }

 .elLink{
    color: white !important;
  }
  .el-icon-folder-opened{
    color: white;
  }

  /deep/ .el-select .el-input__inner {
    border-color: #fff !important;
  }
    /deep/ .el-dialog {
    background: #303030;
  }
  /deep/.el-range-editor.is-active,
  .el-range-editor.is-active:hover,
  .el-select .el-input.is-focus .el-input__inner {
    border: 1px solid;
  }
  /deep/.el-dialog__title {
    color: white;
  }

}
</style>
